@@ -13,7 +13,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Init;
 # ABSTRACT: Initialize git repository on dzil new
 
-our $VERSION = '2.048';
+our $VERSION = '2.049';
 
 our %transform = (
   lc => sub { lc shift },
@@ -41,6 +41,12 @@ has commit_message => (
     default => 'initial commit',
 );
 
+has stage => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 1,
+);
+
 has commit => (
     is      => 'ro',
     isa     => Bool,
@@ -71,7 +77,7 @@ has config_entries => (
   default => sub { [] },
 );
 
-sub mvp_multivalue_args { qw(config_entries remotes push_url) }
+sub mvp_multivalue_args { qw(config_entries remotes push_urls) }
 sub mvp_aliases { return { config => 'config_entries', remote => 'remotes', push_url => 'push_urls' } }
 
 sub after_mint {
@@ -83,29 +89,35 @@ sub after_mint {
 
     foreach my $configSpec (@{ $self->config_entries }) {
       my ($option, $value) = split ' ', _format_string($configSpec, $self), 2;
+      $self->log_fatal("invalid syntax for $configSpec!") if not defined $value;
       $self->log_debug("Configuring $option $value");
       $git->config($option, $value);
     }
 
-    $git->add("$opts->{mint_root}");
+    $git->add("$opts->{mint_root}") unless ! $self->stage;
     if ($self->commit) {
       my $message = 'Made initial commit';
       if (length $self->branch) {
         $git->checkout('-b', $self->branch);
         $message .= ' on branch ' . $self->branch;
       }
-      $git->commit({message => _format_string($self->commit_message, $self)});
+      $git->commit({
+              message => _format_string($self->commit_message, $self),
+              'allow-empty' => 1,
+          });
       $self->log($message);
     }
 
     foreach my $remoteSpec (@{ $self->remotes }) {
       my ($remote, $url) = split ' ', _format_string($remoteSpec, $self), 2;
+      $self->log_fatal("invalid syntax for $remoteSpec!") if not defined $url;
       $self->log_debug("Adding remote $remote as $url");
       $git->remote(add => $remote, $url);
     }
 
     foreach my $remoteSpec (@{ $self->push_urls }) {
       my ($remote, $url) = split ' ', _format_string($remoteSpec, $self), 2;
+      $self->log_fatal("invalid syntax for $remoteSpec!") if not defined $url;
       $self->log_debug("Setting push URL for remote $remote to $url");
       $git->remote('set-url' => $remote, '--push' => $url);
     }
@@ -126,7 +138,7 @@ Dist::Zilla::Plugin::Git::Init - Initialize git repository on dzil new
 
 =head1 VERSION
 
-version 2.048
+version 2.049
 
 =head1 SYNOPSIS
 
@@ -134,8 +146,9 @@ In your F<profile.ini>:
 
     [Git::Init]
     commit_message = initial commit  ; this is the default
+    stage = 1                        ; this is the default
     commit = 1                       ; this is the default
-    branch =                         ; this is the default (means master)
+    branch =                         ; this is the default (uses init.defaultBranch config)
     remote = origin https://github.com/USERNAME/%N.git ; no default
     push_url = origin git@github.com:USERNAME/%{lc}N.git ; no default
     config = user.email USERID@cpan.org  ; there is no default
@@ -154,13 +167,19 @@ The plugin accepts the following options:
 =item * commit_message - the commit message to use when checking in
 the newly-minted dist. Defaults to C<initial commit>.
 
+=item * stage - if true (the default), stage (add to Git index)
+all files in the newly-minted dist directory. If commit option
+is true and stage is false, Git will create an empty commit.
+An empty commit is a valid commit and can be used
+as the first commit (root commit) in a repository.
+
 =item * commit - if true (the default), commit the newly-minted dist.
 If set to a false value, add the files to the Git index but don't
 actually make a commit.
 
 =item * branch - the branch name under which the newly-minted dist is checked
 in (if C<commit> is true). Defaults to an empty string, which means that
-the Git default branch is used (master).
+the Git default branch is used (whatever you have configured in `git config init.defaultBranch`).
 
 =item * config - a config setting to make in the repository.  No
 config entries are made by default.  A setting is specified as
